@@ -45,7 +45,6 @@ struct _BjbControllerPrivate
   gchar          *needle ;
   BijiCollection *collection;
   GtkTreeModel   *model ;
-  GtkTreeModel   *completion;
 
   BjbWindowBase  *window;
 
@@ -91,7 +90,6 @@ bjb_controller_init (BjbController *self)
 {
   BjbControllerPrivate *priv  ;
   GtkListStore     *store ;
-  GtkListStore     *completion ;
 
   priv = self->priv = G_TYPE_INSTANCE_GET_PRIVATE
     (self, BJB_TYPE_CONTROLLER, BjbControllerPrivate);
@@ -114,8 +112,6 @@ bjb_controller_init (BjbController *self)
   priv->collection = NULL;
   priv->connected = FALSE;
 
-  completion  = gtk_list_store_new (1, G_TYPE_STRING);
-  priv->completion = GTK_TREE_MODEL (completion);
 }
 
 static void
@@ -133,7 +129,6 @@ bjb_controller_finalize (GObject *object)
 
   g_object_unref (priv->model);
 
-  g_object_unref (priv->completion);
   g_free (priv->needle);
   g_list_free (priv->items_to_show);
 
@@ -258,6 +253,12 @@ bjb_controller_add_item (BjbController *self,
   g_return_if_fail (BIJI_IS_ITEM (item));
   store = GTK_LIST_STORE (self->priv->model);
 
+  /* Only append notes which are not templates. Currently useless */
+  if (BIJI_IS_NOTE_OBJ (item)
+      && biji_note_obj_is_template (BIJI_NOTE_OBJ (item)))
+    return;
+
+
   if (sibling)
     gtk_list_store_insert_before (store, &iter, sibling);
 
@@ -267,10 +268,6 @@ bjb_controller_add_item (BjbController *self,
   else
     gtk_list_store_append (store, &iter);
 
-  /* Only append notes which are not templates. Currently useless */
-  if (BIJI_IS_NOTE_OBJ (item)
-      && biji_note_obj_is_template (BIJI_NOTE_OBJ (item)))
-    return;
 
   /* First , if there is a gd main view , and if gd main view
    * is a list, then load the smaller emblem */
@@ -515,38 +512,6 @@ on_needle_changed (BjbController *self)
   g_signal_emit (self, bjb_controller_signals[SEARCH_CHANGED], 0);
 }
 
-static void
-add_item_to_completion (BijiItem *item, BjbController *self)
-{
-  GtkListStore *store;
-  GtkTreeIter iter;
-
-  store = GTK_LIST_STORE (self->priv->completion);
-
-  // Search Tag.
-  gtk_list_store_append (store, &iter);
-  gtk_list_store_set (store, 
-                      &iter, 
-                      0, 
-                      biji_item_get_title (item),
-                      -1);
-}
-
-static void
-refresh_completion(BjbController *self)
-{
-  GList *items;
-
-  gtk_list_store_clear (GTK_LIST_STORE (self->priv->completion));
-  items = biji_note_book_get_items (self->priv->book);
-
-  if (items)
-  {
-    g_list_foreach (items, (GFunc) add_item_to_completion, self);
-    g_list_free (items);
-  }
-}
-
 
 /* Depending on the change at data level,
  * the view has to be totaly refreshed or just amended */
@@ -558,6 +523,7 @@ on_book_changed (BijiNoteBook           *book,
 {
   BjbControllerPrivate *priv = self->priv;
   BijiItem    *item = BIJI_ITEM (biji_item);
+  BijiNoteObj *note = NULL;
   GtkTreeIter iter;
   GtkTreeIter *p_iter = &iter;
 
@@ -613,7 +579,7 @@ on_book_changed (BijiNoteBook           *book,
       if (bjb_controller_get_iter (self, item, &p_iter))
         gtk_list_store_remove (GTK_LIST_STORE (priv->model), p_iter);
 
-      priv->items_to_show = g_list_remove (priv->items_to_show, item);
+      priv->items_to_show = g_list_remove (priv->items_to_show, note);
       notify_displayed_items_changed (self);
       break;
 
@@ -623,8 +589,6 @@ on_book_changed (BijiNoteBook           *book,
         bjb_window_base_set_active (self->priv->window, TRUE);
   }
 
-  /* FIXME we refresh the whole completion model each time */
-  refresh_completion(self);
   g_mutex_unlock (&priv->mutex);
 }
 
@@ -746,10 +710,6 @@ void
 bjb_controller_set_book (BjbController *self, BijiNoteBook  *book )
 {
   self->priv->book = book ;
-  
-  /* Only update completion.
-   * Notes model is updated when needle changes */
-  refresh_completion(self);
 }
 
 void
@@ -777,12 +737,6 @@ bjb_controller_get_model  (BjbController *self)
   return self->priv->model ;
 }
 
-GtkTreeModel *
-bjb_controller_get_completion(BjbController *self)
-{
-  return self->priv->completion ;
-}
-
 
 gboolean
 bjb_controller_shows_item (BjbController *self)
