@@ -76,7 +76,8 @@ struct _BjbMainViewPriv {
   gulong view_selection_changed;
 };
 
-G_DEFINE_TYPE (BjbMainView, bjb_main_view, GTK_TYPE_BOX);
+
+G_DEFINE_TYPE (BjbMainView, bjb_main_view, GTK_TYPE_GRID);
 
 static void
 bjb_main_view_init (BjbMainView *object)
@@ -180,7 +181,7 @@ void
 switch_to_note_view (BjbMainView *self, BijiNoteObj *note)
 {
   bjb_main_view_disconnect_handlers (self);
-  bjb_window_base_switch_to_note (BJB_WINDOW_BASE (self->priv->window), note);
+  bjb_window_base_switch_to_item (BJB_WINDOW_BASE (self->priv->window), BIJI_ITEM (note));
 }
 
 static void
@@ -344,6 +345,8 @@ on_item_activated (GdMainView        * gd,
   gtk_tree_model_get_iter (model, &iter, (GtkTreePath*) path);
   gtk_tree_model_get (model, &iter, GD_MAIN_COLUMN_URI, &item_path,-1);
 
+  g_return_val_if_fail (item_path != NULL, FALSE); // #709197
+
   /* Switch to that item */
   book = bjb_window_base_get_book (view->priv->window); 
   to_open = biji_note_book_get_item_at_path (book, item_path);
@@ -425,37 +428,192 @@ bjb_main_view_connect_signals (BjbMainView *self)
                               G_CALLBACK (on_drag_data_received), self);
 }
 
+void
+__destroy_n_notify__ (gpointer data)
+{
+}
+
+
+
+BijiItem *
+_get_item_for_tree_path (GtkTreeModel *tree_model,
+                         GtkTreeIter *iter,
+                         BjbMainView *self)
+{
+  BijiItem *retval;
+  gchar *uuid;
+
+
+  retval = NULL;
+  uuid = NULL;
+  gtk_tree_model_get (tree_model,
+                      iter,
+                      GD_MAIN_COLUMN_ID,
+                      &uuid,
+                      -1);
+
+
+  if (uuid != NULL)
+  {
+    retval = biji_note_book_get_item_at_path (
+               bjb_window_base_get_book (self->priv->window), uuid);
+    g_free (uuid);
+  }
+
+  return retval;
+}
+
+
+
+static void
+render_type     (GtkTreeViewColumn *tree_column,
+                 GtkCellRenderer *cell,
+                 GtkTreeModel *tree_model,
+                 GtkTreeIter *iter,
+                 gpointer data)
+{
+  BijiItem *item;
+  const gchar *str;
+  BjbMainView *self;
+
+  self = data;
+  str = NULL;
+  item = _get_item_for_tree_path (tree_model, iter, self);
+
+  if (item != NULL)
+  {
+    if BIJI_IS_COLLECTION (item)
+      str= _("Collection");
+
+    else if BIJI_IS_NOTE_OBJ (item)
+      str = _("Note");
+  }
+
+  if (str != NULL)
+    g_object_set (cell, "text", str, NULL);
+}
+
+
+
+static void
+render_where    (GtkTreeViewColumn *tree_column,
+                 GtkCellRenderer *cell,
+                 GtkTreeModel *tree_model,
+                 GtkTreeIter *iter,
+                 gpointer data)
+{
+  BijiItem *item;
+  const gchar *str;
+  BjbMainView *self;
+
+  self = data;
+  item = _get_item_for_tree_path (tree_model, iter, self);
+
+  if (item != NULL)
+  {
+    str = biji_item_get_place (item);
+    g_object_set (cell, "text", str, NULL);
+  }
+}
+
+
+
+static void
+render_date     (GtkTreeViewColumn *tree_column,
+                 GtkCellRenderer *cell,
+                 GtkTreeModel *tree_model,
+                 GtkTreeIter *iter,
+                 gpointer data)
+{
+  BijiItem *item;
+  gchar *str;
+  BjbMainView *self;
+
+  self = data;
+  item = _get_item_for_tree_path (tree_model, iter, self);
+
+  if (item != NULL)
+  {
+    str = biji_get_time_diff_with_time (biji_item_get_mtime (item));
+    g_object_set (cell, "text", str, NULL);
+  }
+}
+
+
+static void
+add_list_renderers (BjbMainView *self)
+{
+  GtkWidget *generic;
+  GtkCellRenderer *cell;
+
+  generic =  gd_main_view_get_generic_view (self->priv->view);
+
+  /* Type Renderer */
+  cell = gd_styled_text_renderer_new ();
+  gd_styled_text_renderer_add_class (GD_STYLED_TEXT_RENDERER (cell), "dim-label");
+  gtk_cell_renderer_set_padding (cell, 16, 0);
+
+  gd_main_list_view_add_renderer (GD_MAIN_LIST_VIEW (generic),
+                                  cell,
+                                  render_type,
+                                  self,
+                                  __destroy_n_notify__);
+
+
+  /* Where Renderer */
+  cell = gd_styled_text_renderer_new ();
+  gd_styled_text_renderer_add_class (GD_STYLED_TEXT_RENDERER (cell), "dim-label");
+  gtk_cell_renderer_set_padding (cell, 16, 0);
+
+  gd_main_list_view_add_renderer (GD_MAIN_LIST_VIEW (generic),
+                                  cell,
+                                  render_where,
+                                  self,
+                                  __destroy_n_notify__);
+
+
+  /* Date renderer */
+  cell = gtk_cell_renderer_text_new ();
+  gtk_cell_renderer_set_padding (cell, 32, 0);
+
+  gd_main_list_view_add_renderer (GD_MAIN_LIST_VIEW (generic),
+                                  cell,
+                                  render_date,
+                                  self,
+                                  __destroy_n_notify__);
+
+}
+
+
 static void
 bjb_main_view_constructed(GObject *o)
 {
   BjbMainView          *self;
-  GtkBox               *vbox; //self, too
   BjbMainViewPriv      *priv;
 
   G_OBJECT_CLASS (bjb_main_view_parent_class)->constructed(G_OBJECT(o));
 
   self = BJB_MAIN_VIEW(o);
-  priv = self->priv ;
-  vbox = GTK_BOX (self);
+  priv = self->priv;
 
-  gtk_box_set_homogeneous (vbox, FALSE);
-  gtk_box_set_spacing (vbox, 0);
   gtk_orientable_set_orientation (GTK_ORIENTABLE (self), GTK_ORIENTATION_VERTICAL);
-
   priv->view = gd_main_view_new (DEFAULT_VIEW);
 
   /* Main view */
   gd_main_view_set_selection_mode (priv->view, FALSE);
+  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (priv->view),
+                                       GTK_SHADOW_NONE);
   gd_main_view_set_model (priv->view, bjb_controller_get_model(priv->controller));
-  gtk_box_pack_start (vbox, GTK_WIDGET (priv->view), TRUE, TRUE, 0);
+  gtk_container_add (GTK_CONTAINER (self), GTK_WIDGET (priv->view));
+
 
   /* Load more */
   priv->load_more = bjb_load_more_button_new (priv->controller);
-  gtk_box_pack_start (vbox, priv->load_more, FALSE, FALSE, 0);
+  gtk_container_add (GTK_CONTAINER (self), priv->load_more);
 
   /* Selection Panel */
   priv->select_bar = bjb_selection_toolbar_new (priv->view, self);
-  gtk_box_pack_start (vbox, GTK_WIDGET (priv->select_bar), FALSE, FALSE, 0);
+  gtk_container_add (GTK_CONTAINER (self), GTK_WIDGET (priv->select_bar));
 
   /* Drag n drop */
   gtk_drag_dest_set (GTK_WIDGET (priv->view), GTK_DEST_DEFAULT_ALL,
@@ -555,8 +713,11 @@ bjb_main_view_get_view_type (BjbMainView *view)
 }
 
 void
-bjb_main_view_set_view_type (BjbMainView *view, GdMainViewType type)
+bjb_main_view_set_view_type (BjbMainView *self, GdMainViewType type)
 {
-  gd_main_view_set_view_type (view->priv->view, type);
+  gd_main_view_set_view_type (self->priv->view, type);
+
+  if (type == GD_MAIN_VIEW_LIST)
+    add_list_renderers (self);
 }
 
