@@ -104,7 +104,6 @@ bjb_window_base_constructed (GObject *obj)
   GList *icons = NULL;
   GdkPixbuf *bjb ;
   GError *error = NULL;
-  GtkWidget *revealer;
 
   G_OBJECT_CLASS (bjb_window_base_parent_class)->constructed (obj);
 
@@ -155,8 +154,7 @@ bjb_window_base_constructed (GObject *obj)
 
   /* Search entry toolbar */
   priv->search_bar = bjb_search_toolbar_new (GTK_WIDGET (obj), priv->controller);
-  revealer = bjb_search_toolbar_get_revealer (priv->search_bar);
-  gtk_box_pack_start (GTK_BOX (priv->vbox), GTK_WIDGET (revealer), FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (priv->vbox), GTK_WIDGET (priv->search_bar), FALSE, FALSE, 0);
 
   /* UI : stack for different views */
   priv->stack = GTK_STACK (gtk_stack_new ());
@@ -333,7 +331,7 @@ bjb_window_base_switch_to (BjbWindowBase *bwb, BjbWindowViewType type)
 }
 
 void
-bjb_window_base_switch_to_note (BjbWindowBase *bwb, BijiNoteObj *note)
+bjb_window_base_switch_to_item (BjbWindowBase *bwb, BijiItem *item)
 {
   BjbWindowBasePriv *priv = bwb->priv;
   GtkWidget *w = GTK_WIDGET (bwb);
@@ -342,17 +340,23 @@ bjb_window_base_switch_to_note (BjbWindowBase *bwb, BijiNoteObj *note)
   bjb_search_toolbar_fade_out (priv->search_bar);
   destroy_note_if_needed (bwb);
 
-  priv->note = note;
-  priv->note_overlay = gtk_overlay_new ();
+  if (BIJI_IS_NOTE_OBJ (item))
+  {
 
-  gtk_stack_add_named (priv->stack, priv->note_overlay, "note-view");
-  priv->note_view = bjb_note_view_new (w, priv->note_overlay, note);
+    BijiNoteObj *note = BIJI_NOTE_OBJ (item);
 
-  g_object_add_weak_pointer (G_OBJECT (priv->note_view),
-                             (gpointer *) &priv->note_view);
+    priv->note = note;
+    priv->note_overlay = gtk_overlay_new ();
 
-  bjb_window_base_switch_to (bwb, BJB_WINDOW_BASE_NOTE_VIEW);
-  gtk_widget_show_all (w);
+    gtk_stack_add_named (priv->stack, priv->note_overlay, "note-view");
+    priv->note_view = bjb_note_view_new (w, priv->note_overlay, note);
+
+    g_object_add_weak_pointer (G_OBJECT (priv->note_view),
+                               (gpointer *) &priv->note_view);
+
+    bjb_window_base_switch_to (bwb, BJB_WINDOW_BASE_NOTE_VIEW);
+    gtk_widget_show_all (w);
+  }
 }
 
 BjbWindowViewType
@@ -395,12 +399,14 @@ bjb_window_base_get_main_view (BjbWindowBase *self)
 gboolean
 bjb_window_base_get_show_search_bar (BjbWindowBase *self)
 {
+
   /* There is no search bar at startup,
    * when main toolbar is first built... */
   if (!self->priv->search_bar)
     return FALSE;
 
-  return bjb_search_toolbar_is_shown (self->priv->search_bar);
+  return gtk_search_bar_get_search_mode (
+            GTK_SEARCH_BAR (self->priv->search_bar));
 }
 
 gboolean
