@@ -14,7 +14,8 @@
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.*/
 
-#include "biji-zeitgeist.h"
+
+#ifdef BUILD_ZEITGEIST
 
 #include <libbiji.h>
 #include "biji-zeitgeist.h"
@@ -29,6 +30,7 @@ biji_zeitgeist_init (void)
   ZeitgeistDataSourceRegistry *zg_dsr = NULL;
   ZeitgeistLog *log;
 
+
   log = zeitgeist_log_new ();
   event = zeitgeist_event_new_full (
     NULL, NULL, "application://bijiben.desktop", NULL, NULL);
@@ -64,7 +66,7 @@ on_find_create_event (GObject *log,
 
   if (error)
   {
-    g_warning ("Error reading results: %s", error->message);
+    g_message ("Error reading results: %s", error->message);
     g_error_free (error);
     return;
   }
@@ -168,3 +170,5 @@ insert_zeitgeist (BijiNoteObj *note,
   if (g_strcmp0 (zg_interpretation, ZEITGEIST_ZG_MODIFY_EVENT) ==0)
     check_insert_create_zeitgeist (note);
 }
+
+#endif /* BUILD_ZEITGEIST */
