@@ -21,6 +21,7 @@
 #include <glib-object.h>
 #include <glib/gi18n.h>  // translate providers type
 
+#include "../biji-info-set.h"
 #include "../biji-note-book.h"
 
 G_BEGIN_DECLS
@@ -64,15 +65,54 @@ struct BijiProviderClass_
   GObjectClass parent_class;
 
 
+/* Each Provider subclass instance owns its own BijiProviderInfo
+ * to signal name, icon, or whatever useful info.
+ * datasource is only needed for actual providers,
+ * ie. persistent data source */
+
   const BijiProviderInfo*    (*get_info)              (BijiProvider *provider);
   
 
+  /* When a provider is loaded, notify the book to transmit the items */
+
   void                       (*notify_loaded)         (BijiProvider *provider,
                                                        GList *loaded_items);
 
 
-  BijiNoteObj*               (*create_note)           (BijiProvider *provider,
+  /* Create a single note and let the provider handle things.
+   * Only works from raw text.
+   * Does not allow to trick color or dates */
+
+  BijiNoteObj*               (*create_new_note)       (BijiProvider *provider,
                                                        gchar        *content);
+
+  /* Creates a single note representing some existing data,
+   * with title, content, dates, html, color.
+   * The caller should set as many fields as possible.
+   * The provider should ensure as much as possible to handle
+   * NULL values properly, if any.
+   * Providers will discard assigned values they do not handle.
+   * Local provider is supposed to handle everything.
+   *
+   * Suggested path : if possible, the provider should preserve
+   * the file name. If an import provider is asked to import a file,
+   * first check the item does not exist yet
+   * with same path (basename). ie. do not import twice the same note.
+   *
+   * the info set is not supposed to store any url.
+   * otherwise, you might expect it to be lost.
+   *
+   * TODO: rebase startup code on local provider create note full when good enough
+   * TODO: owncloud provider (to handle importing) */
+
+  BijiNoteObj*               (*create_note_full)      (BijiProvider *provider,
+                                                       gchar        *suggested_path,
+                                                       BijiInfoSet  *info,
+                                                       gchar        *html,
+                                                       GdkRGBA      *color);
+
+
+   /* TODO : (*create_collection). Add a flag into provider info? */
 };
 
 
